import { Idl } from '@coral-xyz/anchor';
import { Idl as Idl$2 } from '@coral-xyz/anchor-new';
import { Idl as Idl$1 } from '@solanafm/kinobi-lite';

declare enum CHAIN_ID {
    SOLANA_MAINNET = "solana-mainnet",
    SOLANA_DEVNET = "solana-devnet",
    SOLANA_TESTNET = "solana-testnet"
}

type createProgramIdlInstanceOptions = {
    baseUrl?: string;
    apiKey?: string;
};
/**
 * Represents the response of a program.
 */
type ProgramResponse = {
    /**
     * The hash of the program.
     */
    programHash: string;
    /**
     * Information about the Program.
     */
    programInformation: ProgramInformation;
    /**
     * Information about the IDL of the program.
     */
    idlInformation?: IdlInformation;
};
/**
 * Information about a program.
 */
type ProgramInformation = {
    /**
     * The slot number where the program was deployed.
     */
    slotDeployed?: number;
    /**
     * Whether the program has an IDL.
     */
    hasIdl: boolean;
    /**
     * Whether the program is closed.
     */
    isClosed: boolean;
};
/**
 * Information about the IDL (Interface Definition Language) of a program.
 */
type IdlInformation = {
    /**
     * The slot number where the IDL was deployed.
     */
    slotDeployed?: number;
    /**
     * The name of the IDL.
     */
    idlName?: string;
    /**
     * The version of the IDL.
     */
    idlVersion?: string;
    /**
     * The type of the IDL.
     */
    idlType?: string;
    /**
     * The URL of the IDL.
     */
    idlUrl?: string;
    /**
     * Whether the IDL has accounts.
     */
    hasAccounts?: boolean;
    /**
     * Whether the IDL has events.
     */
    hasEvents?: boolean;
    /**
     * The IDL object.
     */
    idl?: Idl | Idl$1 | string;
};

type IdlTypes = Idl$1 | Idl | Idl$2 | string;
/**
 * A map of program IDs to a map of slot numbers to IDL types.
 * The IDL types can be either ShankIdl, AnchorIdl, or string.
 * If the slot number is 0, then it means that this is the latest idl that the local repository has.
 * 0 should only be used when the IDLRepository only has 1 IDL for a given program.
 */
declare const IdlRepository: Map<string, Map<number, IdlTypes> | null>;
/**
 * Retrieves the local IDL for a given program ID and slot number from the IDL repository map.
 * If the program ID exists in the map, it returns the IDL for the specified slot number if provided,
 * or the latest IDL if no slot number is provided.
 * If the program ID does not exist in the map, it returns undefined.
 * @param {string} programId - The program ID for the IDL.
 * @param {number} [slot] - The slot number for the IDL.
 * @param {Map<string, Map<number, IdlTypes> | null>} [idlRepoMap=IdlRepository] - The IDL repository map to retrieve the IDL from.
 * @returns - An object containing the IDL and the slot number it was deployed at (if applicable).
 */
declare const getLocalIdl: (programId: string, slot?: number, idlRepoMap?: Map<string, Map<number, IdlTypes> | null>) => {
    idl?: IdlTypes | null;
    slotDeployed?: number;
};
/**
 * Adds an IDL to the given IDL repository map for the specified program ID and slot
 * If the program ID already exists in the map, the IDL is added to the existing nested idl map
 * If the program ID does not exist in the map, a new nested idl map is created with the IDL added to it
 * @param {Map<string, Map<number, IdlTypes>>} idlRepoMap - The IDL repository map to add the IDL to
 * @param {string} programId - The Program ID for the IDL
 * @param {IdlTypes} idl - The IDL to add to the repository
 * @param {number} [slot] - The slot number the IDL was generated at
 * @returns {Map<string, Map<number, IdlTypes> | null>} - The updated IDL repository map that can be used to store in memory
 */
declare const addIdlToMap: (idlRepoMap: Map<string, Map<number, IdlTypes> | null>, programId: string, idl: IdlTypes, slot?: number) => Map<string, Map<number, IdlTypes> | null>;

interface IdlItem {
    programId: string;
    idl: Idl | Idl$2 | Idl$1 | string;
    idlType: "anchor" | "anchorV1" | "shank" | "kinobi";
    idlSlotVersion?: number;
    chainId?: CHAIN_ID;
}
type FetchProgramIdlOptions = {
    slotContext?: number;
    chainId?: CHAIN_ID;
} & createProgramIdlInstanceOptions;
/**
 * Checks if the given IDL is an Anchor IDL.
 * @param {AnchorIdl | AnchorV1Idl | ShankIdl | string} idl - The IDL to check.
 * @returns {idl is AnchorIdl} - True if the IDL is an Anchor IDL, false otherwise.
 */
declare const checkIdlIsAnchor: (idl: Idl | Idl$2 | Idl$1 | string) => idl is Idl;
/**
 * Checks if the given IDL is an Anchor 0.3.0 IDL.
 * @param {AnchorIdl | AnchorV1Idl | ShankIdl | string} idl - The IDL to check.
 * @returns {idl is AnchorIdl} - True if the IDL is an Anchor IDL, false otherwise.
 */
declare const checkIdlIsAnchorV1: (idl: Idl | Idl$2 | Idl$1 | string) => idl is Idl$2;
/**
 * Checks if the given IDL is an Shank IDL.
 * @param {AnchorIdl | AnchorV1Idl | ShankIdl | string} idl - The IDL to check.
 * @returns {idl is ShankIdl} - True if the IDL is an Shank IDL, false otherwise.
 */
declare const checkIdlIsShank: (idl: Idl | Idl$2 | Idl$1 | string) => idl is Idl$1;
/**
 * Checks if the given IDL is a string.
 * @param {AnchorIdl | AnchorV1Idl | ShankIdl | string} idl - The IDL to check.
 * @returns {idl is string} - True if the IDL is a string, false otherwise.
 */
declare const checkIdlIsString: (idl: Idl | Idl$2 | Idl$1 | string) => idl is string;
/**
 * Retrieves the IDL for a given program hash
 * @param {string} programHash - The program hash to fetch the IDL for
 * @param {FetchProgramIdlOptions} [options] - Options for fetching the program IDL
 * @param {Map<string, Map<number, IdlTypes> | null>} [idlRepoMap] - A map of program hashes to their IDLs
 * @returns {Promise<IdlItem | null>} - The IDL for the program hash, or null if it cannot be found
 * @example
 * ```typescript
 * const idl = await getProgramIdl("KLend2g3cP87fffoy8q1mQqGKjrxjC8boSyAYavgmjD", { slotContext: 123 });
 * ```
 */
declare const getProgramIdl: (programHash: string, options?: FetchProgramIdlOptions, idlRepoMap?: Map<string, Map<number, IdlTypes> | null>) => Promise<IdlItem | null>;
/**
 * Retrieves the IDLs for multiple program hashes
 * @param {string[]} programHashes - The program hashes to fetch the IDLs for
 * @param {FetchProgramIdlOptions} [options] - Options for fetching the program IDLs
 * @param {Map<string, Map<number, IdlTypes> | null>} [idlRepoMap] - A map of program hashes to their IDLs
 * @returns {Promise<IdlItem[]>} - The IDLs for the program hashes
 * @example
 * ```typescript
 * const idls = await getMultipleProgramIdls(["KLend2g3cP87fffoy8q1mQqGKjrxjC8boSyAYavgmjD", "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA"], { slotContext: 123 });
 * ```
 */
declare const getMultipleProgramIdls: (programHashes: string[], options?: FetchProgramIdlOptions, idlRepoMap?: Map<string, Map<number, IdlTypes> | null>) => Promise<IdlItem[]>;

declare const checkForIdlPatches: (idlMetaResponse: ProgramResponse) => ProgramResponse;

export { IdlItem, IdlRepository, IdlTypes, addIdlToMap, checkForIdlPatches, checkIdlIsAnchor, checkIdlIsAnchorV1, checkIdlIsShank, checkIdlIsString, getLocalIdl, getMultipleProgramIdls, getProgramIdl };
